var _kwRev= 0;
var _kwDotNetNS= "KioWareDotNet.KioWareDotNet";
var _kioUtilsItf= (typeof(KioWareUtils)=="object" ? KioWareUtils : (typeof(KioUtils)=="object" ? KioUtils : window.external));
var _kioAppItf= typeof(KioApp)=="object" ? KioApp : null;

KioWare =
{
	GetProperty: function(n)
	{
		if(this.IsKioWarePlatform())
			return _kioAppItf.GetProperty(n);
		return _kioUtilsItf.getKioProperty(n);
	},

	GetRev: function()
	{
		if(_kwRev)
			return _kwRev;
		try
		{
			if(this.IsKioWarePlatform())
				_kwRev= KioApp.GetRev();
			else
			{
				_kwRev= this.GetProperty("SVNRev");
				_kwRev= _kwRev.replace(/[^0-9]/g, "");
				_kwRev= parseInt(_kwRev);
			}
		}
		catch(err){_kwRev= 0;}
		return _kwRev;
	},

	Is: function()
	{
		return (this.GetRev() > 0);
	},

	IsKioWare: function()
	{
		return this.Is();
	},
	//More specific than IsKioWare
	IsKioWareAndroid: function()
	{
		return (!this.IsKioWarePlatform() && _kioUtilsItf != window.external);
	},
	//More specific than IsKioWare
	IsKioWareWindows: function()
	{
		return (!this.IsKioWarePlatform() && !this.IsKioWareAndroid() && this.Is());
	},
	//More specific than IsKioWare
	IsKioWarePlatform: function()
	{
		return (_kioAppItf!=null && typeof(KioWareUtils)!="object");
	},
	//Remember to set up a scripting access list
	Execute: function(path)
	{
		if(this.IsKioWareAndroid())
			_kioUtilsItf.runAppByLabel(path);
		else
			_kioUtilsItf.Execute(path);
	},

	Print: function()
	{
		window.external.print();
	},

	LogOff: function()
	{
		if(this.IsKioWarePlatform())
			_kioAppItf.EndSession();
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.endSession();
		else
			_kioUtilsItf.logoff();
	},

	CloseAllPopups: function()
	{
		window.external.CloseAllPopups();
	},

	ShowKeyboard: function()
	{
		window.external.StartVirtualKeyboard();
	},
	
	ShowGenericKeyboard: function()
	{
		window.external.KioShowGenericKeyboard();
	},
	
	HideGenericKeyboard: function()
	{
		window.external.KioHideGenericKeyboard();
	},

	LogSessionBegin: function()
	{
		window.external.SetSessionBegin();
	},

	LogPageStat: function(pageTitle, url)
	{
		window.external.WriteLogEntry(pageTitle, url);
	},    

	LogSessionEnd: function()
	{
		window.external.WriteEndSessionRecord();
	},

	LogInfo: function(msg)
	{
		if(this.IsKioWarePlatform())
			_kioAppItf.LogInfo(msg);
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.LogInfo(msg);
		else
			_kioUtilsItf.KioEventLog(0, msg);
	},

	LogWarn: function(msg)
	{
		if(this.IsKioWarePlatform())
			_kioAppItf.LogWarn(msg);
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.LogWarn(msg);
		else
			_kioUtilsItf.KioEventLog(1, msg);
	},

	LogErr: function(msg)
	{
		if(this.IsKioWarePlatform())
			_kioAppItf.LogErr(msg);
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.LogErr(msg);
		else
			_kioUtilsItf.KioEventLog(2, msg);
	},

	DialNumber: function(name, number, showDialPad)
	{
		window.external.KioDialNumber(name, number, showDialPad);
	},

	RecordVideo: function(seconds, filename, enablePreview)
	{
		window.external.KioCaptureVideo(0, filename, seconds, enablePreview);
	},

	PreviewVideo: function(enable)
	{
		window.external.KioPreviewEnabled(0, enable);
	},

	TakePicture: function(filename)
	{
		window.external.KioCaptureVideo(0, filename, 0);
	},

	ScanImage: function(filename)
	{
		window.external.KioReadScan(0, filename);
	},

	GetDeviceStatus: function(deviceName)
	{
		var st;
		try {st= window.external.KioDeviceStatus(deviceName);}
		catch(ex) {st= 0xFFFF;}
		return st;
	},

	//nMonitorAfterFirst is optional (0 by default) and is used to add to the number of the first monitor to access other monitors
	SetSecondMonitorURL: function(url, nMonitorAfterFirst)
	{
		if(nMonitorAfterFirst==null) nMonitorAfterFirst= 0;
		window.external.Browser(2+nMonitorAfterFirst).parentWindow.location= url;
	},
	
	SetSecondMonitorURLTime: function(secondsToShow, nMonitorAfterFirst)
	{
		if(nMonitorAfterFirst==null) nMonitorAfterFirst= 0;
		window.external.Browser(2+nMonitorAfterFirst).parentWindow.external.SecondaryTimer(secondsToShow);
	},

	ShowMessage: function(msg)
	{
		window.external.KioCallObject(_kwDotNetNS, "MessageBox", msg);
	},

	IsUserPresent: function()
	{
		try
		{
			if(this.IsKioWarePlatform())
				return _kioAppItf.IsSessionActive();
			else
				return window.external.KioCallObject(_kwDotNetNS, "get_UserPresent");
		}
		catch(ex){}
		return 0;
	},

	SetUserPresent: function(v)
	{
		if(this.IsKioWarePlatform())
		{
			if(v) _kioAppItf.BeginSession();
			else _kioAppItf.EndSession();
		}
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.setUserPresent(v);
		else
			window.external.KioCallObject(_kwDotNetNS, "set_UserPresent", (v ? true : false));
	},

	TLS_IsManual: function()
	{
		return window.external.KioCallObject(_kwDotNetNS, "TLSession.IsManualMode");
	},

	TLS_StartTimer: function(seconds)
	{
		return window.external.KioCallObject(_kwDotNetNS, "TLSession.StartTimer", seconds);
	},

	TLS_StopTimer: function()
	{
		window.external.KioCallObject(_kwDotNetNS, "TLSession.StopTimer");
	},

	TLS_GetTimeLeft: function()
	{
		return window.external.KioCallObject(_kwDotNetNS, "TLSession.GetCurrentSecondsRemaining");
	},

	IsLicenseValid: function()
	{
		return window.external.KioCallObject(_kwDotNetNS, "ValidateLicenseCode");
	},

	GetNewLicense: function(transNum, authCode, model, licType, expYear, expMonth, expDay, performRestart)
	{
		return window.external.KioCallObject(_kwDotNetNS, 'GetNewKWLicense', transNum, authCode, model, licType, expYear, expMonth, expDay, performRestart);
	},

	ShowFindDialog: function()
	{
		window.external.FindDialog();
	},

	ExitKioWare: function()
	{
		window.external.KioExit();
	},

	IsUrlBlocked: function(url)
	{
		if(this.IsKioWareAndroid())
			return _kioUtilsItf.isUrlBlocked(url);
		return _kioUtilsItf.KioIsUrlBlocked(url);
	},

	GetSpeakerVolume: function()
	{
		if(this.IsKioWarePlatform())
			return _kioUtilsItf.GetMasterVolume();
		else if(this.IsKioWareAndroid())
			return _kioUtilsItf.getMusicVolume();
		return _kioUtilsItf.KioGetSpeakerVolume();
	},

	SetSpeakerVolume: function(percent)
	{
		if(this.IsKioWarePlatform())
			return _kioUtilsItf.SetMasterVolume(percent);
		else if(this.IsKioWareAndroid())
			_kioUtilsItf.setMusicVolume(percent);
		else
			_kioUtilsItf.KioSetSpeakerVolume(percent);
	},

	GetMicVolume: function()
	{
		return window.external.KioGetMicVolume();
	},

	SetMicVolume: function(percent)
	{
		window.external.KioSetMicVolume(percent);
	},

	ClearPrintQueue: function(minSecondsOld)
	{
		window.external.KioClearPrintQueue(minSecondsOld);
	},
	//Can be null: groupName, msg
	AppLog: function(groupName, msg)
	{
		if(this.IsKioWarePlatform())
		{
			window._KioWareLastAppLogId= _kioAppItf.CreateAppLog(groupName, msg);
			return window._KioWareLastAppLogId;
		}
		return _kioUtilsItf.KioAppLog(groupName, msg);
	},
	//Can be null: val
	AppLogData: function(name, val)
	{
		if(this.IsKioWarePlatform()) return _kioAppItf.AddAppLogData(window._KioWareLastAppLogId, name, val?val.toString():null);
		return _kioUtilsItf.KioAppLogData(name, val?val.toString():null);
	}
}